
#include "DHT.h"
#include <OneWire.h> 
#include <DallasTemperature.h>
#include <Wire.h>
#include <SPI.h>
#include <Adafruit_Sensor.h>
#include "Adafruit_BME680.h"

//DS18B20
#define ONE_WIRE_BUS 2 


//DHTxx
#define DHT22PIN 5     // Digital pin connected to the DHT22 sensor
#define DHT11PIN 6     // Digital pin connected to the DHT11 sensor
#define DHTTYPE11 DHT11   // DHT 11
#define DHTTYPE22 DHT22   // DHT 22  (AM2302), AM2321

//BME680
#define BME_SCK 7  //SCL
#define BME_MISO 5 //SDO
#define BME_MOSI 6 //SDA
#define BME_CS 4   //CS

#define SEALEVELPRESSURE_HPA (1013.25)

Adafruit_BME680 bme; // I2C

// Initialize DHT sensor.
DHT dht11(DHT11PIN, DHTTYPE11);
DHT dht22(DHT22PIN, DHTTYPE22);

//Init DS
OneWire oneWire(ONE_WIRE_BUS); 
DallasTemperature sensors(&oneWire);

unsigned long startTime, loopTime, difTime;

float h11, t11, h22, t22, hic11, hic22, tBME, hBME, pBME, gBME, tDS;

void setup() {
  Serial.begin(115200);
  Serial.println("Sensor shootout");

  while (!Serial);
  Serial.println(F("BME680 test"));
  if (!bme.begin()) {
    Serial.println("Could not find a valid BME680 sensor, check wiring!");
    while (1);
  }
  // Set up oversampling and filter initialization
  bme.setTemperatureOversampling(BME680_OS_8X);
  bme.setHumidityOversampling(BME680_OS_2X);
  bme.setPressureOversampling(BME680_OS_4X);
  bme.setIIRFilterSize(BME680_FILTER_SIZE_3);
  bme.setGasHeater(320, 150); // 320*C for 150 ms

  dht11.begin();
  dht22.begin();
  sensors.begin(); 
  Serial.println("t11 (C), h11 (%), , t22 (C), h22 (%), , tBME (C), hBME (%), , tDS (C), , Loop Time(ms)");
  delay(1000);
}

void loop() {
  // Wait a few seconds between measurements.
  startTime = millis();
 
  //DHT11
  h11 = dht11.readHumidity();
  t11 = dht11.readTemperature();

  //DHT22
  h22 = dht22.readHumidity();
  t22 = dht22.readTemperature();

  //BME
  if (! bme.performReading()) {
    Serial.println("Failed to perform reading :(");
    return;
  }
  tBME = bme.temperature;
  hBME = bme.humidity;

  //DS
  sensors.requestTemperatures();
  tDS = sensors.getTempCByIndex(0);

  delay(1000);
  loopTime = millis();
  difTime = loopTime - startTime;
  
  Serial.print(t11);
    Serial.print(", ");
  Serial.print(h11);
    Serial.print(", ");
    Serial.print(", ");
    
  Serial.print(t22);
    Serial.print(", ");
  Serial.print(h22);
    Serial.print(", ");
    Serial.print(", ");

  Serial.print(tBME);
    Serial.print(", ");
  Serial.print(hBME);
    Serial.print(", ");
    Serial.print(", ");

  Serial.print(tDS);
    Serial.print(", ");
    Serial.print(", ");

  Serial.println(difTime);
}
